# Changelog

## 0.13.0 (2026-03-24)

Full Changelog: [v0.12.0...v0.13.0](https://github.com/Nimbleway/webit-client-python/compare/v0.12.0...v0.13.0)

### Features

* **api:** manual updates ([5aa15cc](https://github.com/Nimbleway/webit-client-python/commit/5aa15cc51bcc2a485499269fe893e1beae637e28))


### Bug Fixes

* sanitize endpoint path params ([d23d45f](https://github.com/Nimbleway/webit-client-python/commit/d23d45fef723872847d05232ab8143c8f39110c9))


### Chores

* **internal:** update gitignore ([1cd4840](https://github.com/Nimbleway/webit-client-python/commit/1cd4840ee6dfb40d4419c22580da5592b1a5ea0f))

## 0.12.0 (2026-03-17)

Full Changelog: [v0.11.0...v0.12.0](https://github.com/Nimbleway/webit-client-python/compare/v0.11.0...v0.12.0)

### Features

* **api:** api update ([304ec62](https://github.com/Nimbleway/webit-client-python/commit/304ec625ed7ed96f3b936757dca36881929c35bd))
* **api:** api update ([a64bf4d](https://github.com/Nimbleway/webit-client-python/commit/a64bf4dacfe1a8e922b4ae27abbecaab75c42781))
* **api:** api update ([042d4aa](https://github.com/Nimbleway/webit-client-python/commit/042d4aaf098816d94ed8f29503acc33dda952067))
* **api:** api update ([a1b9a84](https://github.com/Nimbleway/webit-client-python/commit/a1b9a846c30936f0fe4d1a065621f58973f261a1))
* **api:** api update ([d920c47](https://github.com/Nimbleway/webit-client-python/commit/d920c47eab37f4563ed8f14d6d0c31731f81e9d1))
* **api:** api update ([ae80f2c](https://github.com/Nimbleway/webit-client-python/commit/ae80f2c31f4d047c7fa60d4d16e27f5c7eae522a))
* **api:** manual updates ([33379ce](https://github.com/Nimbleway/webit-client-python/commit/33379ce7eb3a58c9be9e3a8a94a42c70424d910b))


### Bug Fixes

* **deps:** bump minimum typing-extensions version ([2d1cab8](https://github.com/Nimbleway/webit-client-python/commit/2d1cab8e2ba6d22408c26c72c153f522937ea973))
* **pydantic:** do not pass `by_alias` unless set ([fb4434b](https://github.com/Nimbleway/webit-client-python/commit/fb4434bb16dd3952941d612e68418f287417cdfa))


### Chores

* **ci:** bump uv version ([474fc3b](https://github.com/Nimbleway/webit-client-python/commit/474fc3b4225e05d5893335835855e835a07073da))
* **ci:** skip uploading artifacts on stainless-internal branches ([5a9f6ee](https://github.com/Nimbleway/webit-client-python/commit/5a9f6ee2df69e455942de679615916593b31f0b9))
* format all `api.md` files ([8535a81](https://github.com/Nimbleway/webit-client-python/commit/8535a81d6d7e80bcc2c633f9b32336fa1944a8c0))
* **internal:** add request options to SSE classes ([8cdf9f5](https://github.com/Nimbleway/webit-client-python/commit/8cdf9f51f656d75a729f83abdfa091fe7d7c5653))
* **internal:** codegen related update ([e29ea85](https://github.com/Nimbleway/webit-client-python/commit/e29ea859886f8f1b3a3a71cf3973ec2db8e4a660))
* **internal:** make `test_proxy_environment_variables` more resilient ([8be7fbc](https://github.com/Nimbleway/webit-client-python/commit/8be7fbc5f03ba001bab15195f1db99d703fde4c7))
* **internal:** make `test_proxy_environment_variables` more resilient to env ([0bf6294](https://github.com/Nimbleway/webit-client-python/commit/0bf6294f5c1a47f0a8e55d10522e31acecb7ef2f))
* **internal:** remove mock server code ([3924032](https://github.com/Nimbleway/webit-client-python/commit/39240325cc8dc1a0f7979223ea5792c948b77ed6))
* **internal:** tweak CI branches ([fa97b52](https://github.com/Nimbleway/webit-client-python/commit/fa97b52fbcf221b06ba880198f874bd30d8b43bb))
* update mock server docs ([ce3e425](https://github.com/Nimbleway/webit-client-python/commit/ce3e425ace8de383e420cab3a087911aa170891e))


### Refactors

* **types:** use `extra_items` from PEP 728 ([6fff51e](https://github.com/Nimbleway/webit-client-python/commit/6fff51e590a4463641741fd7e406d29da212364e))

## 0.11.0 (2026-02-12)

Full Changelog: [v0.10.0...v0.11.0](https://github.com/Nimbleway/webit-client-python/compare/v0.10.0...v0.11.0)

### Features

* **api:** api update ([c11a4b5](https://github.com/Nimbleway/webit-client-python/commit/c11a4b5ec7c23a32c9ca94fd4df6c09a17eae098))

## 0.10.0 (2026-02-12)

Full Changelog: [v0.9.0...v0.10.0](https://github.com/Nimbleway/webit-client-python/compare/v0.9.0...v0.10.0)

### Features

* **api:** api update ([87fd2c3](https://github.com/Nimbleway/webit-client-python/commit/87fd2c35b4638023e136aca41a2368528fdefc38))
* **api:** api update ([7febe0a](https://github.com/Nimbleway/webit-client-python/commit/7febe0a9868bda8a38cd9b9f183bc9b61749b463))
* **api:** api update ([df21bea](https://github.com/Nimbleway/webit-client-python/commit/df21bea6683840df6ba4c09e1cef944465557613))


### Chores

* **internal:** fix lint error on Python 3.14 ([4e5d5b0](https://github.com/Nimbleway/webit-client-python/commit/4e5d5b097739eee2d64b6901f0665e1e50c4a9be))

## 0.9.0 (2026-02-11)

Full Changelog: [v0.8.0...v0.9.0](https://github.com/Nimbleway/webit-client-python/compare/v0.8.0...v0.9.0)

### Features

* **api:** api update ([a310999](https://github.com/Nimbleway/webit-client-python/commit/a310999fa0162b927b55e96ddb02b5716a669dcf))

## 0.8.0 (2026-02-10)

Full Changelog: [v0.7.0...v0.8.0](https://github.com/Nimbleway/webit-client-python/compare/v0.7.0...v0.8.0)

### Features

* **api:** Added extract/async and tasks api ([2186e62](https://github.com/Nimbleway/webit-client-python/commit/2186e62fac10195f1a5a7e1d73b075beee746e3c))
* **api:** api update ([abfe53e](https://github.com/Nimbleway/webit-client-python/commit/abfe53e8d84e41a940128b0c96f0f6fd0bfe49c6))
* **api:** api update ([3e60fcb](https://github.com/Nimbleway/webit-client-python/commit/3e60fcb956faa220ce60bc1a37307e50d4a31a2f))


### Chores

* **internal:** bump dependencies ([ae5f927](https://github.com/Nimbleway/webit-client-python/commit/ae5f927ff4493a8a0e48b27d010c169da00a9594))

## 0.7.0 (2026-02-09)

Full Changelog: [v0.6.0...v0.7.0](https://github.com/Nimbleway/webit-client-python/compare/v0.6.0...v0.7.0)

### Features

* **api:** api update ([ea419a6](https://github.com/Nimbleway/webit-client-python/commit/ea419a6961595418d443f361f30d0cf1b97b5644))
* **api:** manual updates ([d8d33f1](https://github.com/Nimbleway/webit-client-python/commit/d8d33f11ecc9e9aa514733c2b32d14f26276fc80))

## 0.6.0 (2026-02-09)

Full Changelog: [v0.5.0...v0.6.0](https://github.com/Nimbleway/webit-client-python/compare/v0.5.0...v0.6.0)

### Features

* **api:** api update ([abea9f7](https://github.com/Nimbleway/webit-client-python/commit/abea9f7174d07a4324f1c69e77e1300785b92824))
* **api:** api update ([e85e275](https://github.com/Nimbleway/webit-client-python/commit/e85e275458d431a3e329c5899f7962ad8d1ff3e7))

## 0.5.0 (2026-02-08)

Full Changelog: [v0.4.0...v0.5.0](https://github.com/Nimbleway/webit-client-python/compare/v0.4.0...v0.5.0)

### Features

* **api:** Add API v2 ([15ef817](https://github.com/Nimbleway/webit-client-python/commit/15ef8171228fb4a71716d1be09f90eab0a306e7c))
* **api:** Rename to agent ([969c259](https://github.com/Nimbleway/webit-client-python/commit/969c2594f012ed8cfeec8b83bde003e7cd1b418e))

## 0.4.0 (2026-02-08)

Full Changelog: [v0.3.0...v0.4.0](https://github.com/Nimbleway/webit-client-python/compare/v0.3.0...v0.4.0)

### Features

* **api:** Agents ([166f535](https://github.com/Nimbleway/webit-client-python/commit/166f5359a3e867588533c68ac3cc4cd6ba46b2e9))

## 0.3.0 (2026-02-08)

Full Changelog: [v0.2.0...v0.3.0](https://github.com/Nimbleway/webit-client-python/compare/v0.2.0...v0.3.0)

### Features

* **api:** api update ([ba25eef](https://github.com/Nimbleway/webit-client-python/commit/ba25eef3566999ca886772bbb6d1004b37d6f52c))

## 0.2.0 (2026-02-05)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/Nimbleway/webit-client-python/compare/v0.1.0...v0.2.0)

### Features

* **api:** api update ([4d2862f](https://github.com/Nimbleway/webit-client-python/commit/4d2862f53961dc496b9558f6d15c5c536e89586b))
* **api:** manual updates ([df2dfd7](https://github.com/Nimbleway/webit-client-python/commit/df2dfd74a2cabce6af8f7cfdcba89094db0f206e))
* **api:** manual updates ([9e3ba40](https://github.com/Nimbleway/webit-client-python/commit/9e3ba407da0a09725ab0beee872f6c08762524c6))
* **api:** manual updates ([1dc368f](https://github.com/Nimbleway/webit-client-python/commit/1dc368fec9327e88c086cc60c7f92d656b4928d6))

## 0.1.0 (2026-02-05)

Full Changelog: [v0.0.3...v0.1.0](https://github.com/Nimbleway/webit-client-python/compare/v0.0.3...v0.1.0)

### Features

* **api:** api update ([9aae40a](https://github.com/Nimbleway/webit-client-python/commit/9aae40affc9d69a8897530a17e76d52ac946f991))
* **api:** api update ([f6e244b](https://github.com/Nimbleway/webit-client-python/commit/f6e244b0fbc031ec43c212cf24d96a71b49bce25))
* **api:** api update ([6219961](https://github.com/Nimbleway/webit-client-python/commit/6219961ee4f739be035580c9be9f45982f1e6fcc))
* **api:** manual updates ([38d4936](https://github.com/Nimbleway/webit-client-python/commit/38d493651cea8ac555fde0f8dd5f846bf0ee2524))
* **api:** manual updates ([e932f3c](https://github.com/Nimbleway/webit-client-python/commit/e932f3c91f42b2a99b30e10513eaa064f2e99950))
* **client:** add custom JSON encoder for extended type support ([ce9c554](https://github.com/Nimbleway/webit-client-python/commit/ce9c55426b83f8f9662d42e6844e20c1987f11b1))


### Bug Fixes

* **docs:** fix mcp installation instructions for remote servers ([2aefb5f](https://github.com/Nimbleway/webit-client-python/commit/2aefb5fdfa702567b35559d8879b382654a9be09))


### Chores

* configure new SDK language ([8fdf5e0](https://github.com/Nimbleway/webit-client-python/commit/8fdf5e05fa09093681de121f3a6c533dd097589f))

## 0.0.3 (2026-01-25)

Full Changelog: [v0.0.2...v0.0.3](https://github.com/Nimbleway/webit-client-python/compare/v0.0.2...v0.0.3)

### Chores

* update SDK settings ([ce39b97](https://github.com/Nimbleway/webit-client-python/commit/ce39b9788fd6c73153673e36d746251047a5b861))

## 0.0.2 (2026-01-25)

Full Changelog: [v0.0.1...v0.0.2](https://github.com/Nimbleway/webit-client-python/compare/v0.0.1...v0.0.2)

### Chores

* sync repo ([6d4a89f](https://github.com/Nimbleway/webit-client-python/commit/6d4a89f992596917e48a013ba26c74cd9acd6816))
* update SDK settings ([096924f](https://github.com/Nimbleway/webit-client-python/commit/096924f1c75e6f842c600205268c770dd5fc7e66))
* update SDK settings ([9773ffb](https://github.com/Nimbleway/webit-client-python/commit/9773ffb34b7930bed8944c9733fe758fe388db86))
